Name:           virt-who
Version:        0.10
Release:        8%{?dist}
Summary:        Agent for reporting virtual guest IDs to subscription-manager

Group:          System Environment/Base
License:        GPLv2+
URL:            https://fedorahosted.org/virt-who/
Source0:        https://fedorahosted.org/releases/v/i/virt-who/%{name}-%{version}.tar.gz
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

BuildArch:      noarch
BuildRequires:  python2-devel
Requires:       libvirt-python
# python-rhsm 1.10.10 has required call for guestId support
Requires:       python-rhsm >= 1.10.10
# python-suds is required for vSphere support
Requires:       python-suds
# m2crypto is required for Hyper-V support
Requires:       m2crypto
Requires(post): chkconfig
Requires(preun): chkconfig
# This is for /sbin/service
Requires(preun): initscripts

# Mix of patches that has been fixes upstream after 0.10 release
Patch0:         virt-who-0.10-post-release-minor-fixes.patch
# libvirtd: use event loop instead of reconnecting all the time
Patch1:         virt-who-0.10-libvirtd-use-event-loop-for-monitoring.patch
# Fix hypervisorCheckIn function API usage
Patch2:         virt-who-0.10-fix-hypervisorCheckIn-function.patch
# Fix wrong logger usage when processing update errors
Patch3:         virt-who-0.10-fix-wrong-logger-usage.patch
# libvirt: properly handle libvirt shutdown when doing background monitoring
Patch4:         virt-who-0.10-libvirt-handle-shutdown-properly.patch
# esx: disable error when esx host doesn't have guests
Patch5:         virt-who-0.10-esx-disable-error-when-esx-has-no-guest.patch
# hyperv: don't use deprecated md5 module
Patch6:         virt-who-0.10-hyperv-dont-use-deprecated-md5-module.patch
# vdsm and rhevm: fix constructor parameters
Patch7:         virt-who-0.10-fix-vdsm-and-rhevm-constructor-parameters.patch
# subscriptionmanager: fix domain sorting patch
Patch8:         virt-who-0.10-subscriptionmanager-fix-domain-sorting.patch

%description
Agent that collects information about virtual guests present in the system and
report them to the subscription manager.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1


%build


%install
rm -rf $RPM_BUILD_ROOT

make DESTDIR=$RPM_BUILD_ROOT install
mkdir -p %{buildroot}/%{_sharedstatedir}/%{name}
mkdir -p %{buildroot}/%{_sysconfdir}/virt-who.d
touch %{buildroot}/%{_sharedstatedir}/%{name}/key

# Don't run test suite in check section, because it need the system to be
# registered to subscription-manager server

%clean
rm -rf $RPM_BUILD_ROOT

%post
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add virt-who

%preun
if [ $1 -eq 0 ] ; then
    /sbin/service virt-who stop >/dev/null 2>&1
    /sbin/chkconfig --del virt-who
fi

%postun
if [ "$1" -ge "1" ] ; then
    /sbin/service virt-who condrestart >/dev/null 2>&1 || :
fi


%files
%doc README README.hyperv LICENSE
%{_bindir}/virt-who
%{_bindir}/virt-who-password
%{_datadir}/virt-who/
%{_sysconfdir}/rc.d/init.d/virt-who
%attr(600, root, root) %dir %{_sysconfdir}/virt-who.d
%attr(600, root, root) %config(noreplace) %{_sysconfdir}/sysconfig/virt-who
%{_mandir}/man8/virt-who.8.gz
%{_mandir}/man8/virt-who-password.8.gz
%{_mandir}/man5/virt-who-config.5.gz
%attr(600, root, root) %{_sharedstatedir}/%{name}
%ghost %{_sharedstatedir}/%{name}/key


%changelog
* Wed Sep 10 2014 Radek Novacek <rnovacek@redhat.com> 0.10-8
- Fix domain sorting error in vdsm mode
- Resolves: rhbz#1139497

* Fri Aug 29 2014 Radek Novacek <rnovacek@redhat.com> 0.10-7
- vdsm and rhevm: fix constructor parameters
- Resolves: rhbz#1135341

* Fri Aug 08 2014 Radek Novacek <rnovacek@redhat.com> 0.10-6
- esx: disable error when esx host doesn't have guests
- hyperv: don't use deprecated md5 module
- Resolves: rhbz#1126295, rhbz#1126302

* Fri Aug 01 2014 Radek Novacek <rnovacek@redhat.com> 0.10-5
- libvirt: properly handle libvirt shutdown when doing background monitoring
- Resolves: rhbz#1125810

* Tue Jul 29 2014 Radek Novacek <rnovacek@redhat.com> 0.10-4
- Fix wrong usage of hypervisorCheckIn function
- Fix wrong logger usage when processing update errors
- Resolves: rhbz#1123723

* Wed Jul 02 2014 Radek Novacek <rnovacek@redhat.com> 0.10-3
- libvirtd: use event loop instead of reconnecting all the time
- Resolves: rhbz#1113938

* Wed Jun 18 2014 Radek Novacek <rnovacek@redhat.com> 0.10-2
- Add upstream fixes of 0.10 release
- Related: rhbz#1002640

* Tue Jun 03 2014 Radek Novacek <rnovacek@redhat.com> 0.10-1
- Rebase to virt-who-0.10
- Resolves: rhbz#1002640

* Thu Aug 29 2013 Radek Novacek <rnovacek@redhat.com> 0.8-9
- Set SAM mode as default
- Fix esx traversal patch
- Resolves: rhbz#1002058, rhbz#996269

* Thu Aug 22 2013 Radek Novacek <rnovacek@redhat.com> 0.8-8
- Add satellite support
- Handle more than 100 objects in esx traversal
- Resolves: rhbz#1002058, rhbz#996269

* Wed Aug 07 2013 Radek Novacek <rnovacek@redhat.com> 0.8-7
- Use instanceUuid when uuid of virtual machine is empty
- Resolves: rhbz#923757

* Fri Jul 26 2013 Radek Novacek <rnovacek@redhat.com> 0.8-6
- Increase compatibility with ESXi
- Resolves: rhbz#923757

* Thu Oct 25 2012 Radek Novacek <rnovacek@redhat.com> 0.8-5
- Fix adding https:// to ESX url
- Resolves: rhbz#869960

* Wed Oct 24 2012 Radek Novacek <rnovacek@redhat.com> 0.8-4
- Help and manpage improvements
- Resolves: rhbz#868149

* Wed Oct 17 2012 Radek Novacek <rnovacek@redhat.com> 0.8-3
- Fix bugs in Hyper-V support (patch rebased)
- Create PID file ASAP to prevent service stop fails
- Resolves: rhbz#866890

* Thu Oct 11 2012 Radek Novacek <rnovacek@redhat.com> 0.8-2
- Add support for accessing Hyper-V
- Resolves: rhbz#860854

* Wed Sep 26 2012 Radek Novacek <rnovacek@redhat.com> 0.8-1
- Upstream version 0.8
- RFE: command line improvements
- Add support for accessing RHEV-M
- Fix printing tracebacks on terminal
- Resolves: rhbz#808060, rhbz#846788, rhbz#825215

* Thu Apr 26 2012 Radek Novacek <rnovacek@redhat.com> 0.6-6
- Handle unknown libvirt event properly
- Resolves: rhbz#815279

* Wed Apr 18 2012 Radek Novacek <rnovacek@redhat.com> 0.6-5
- Enable debug output to be written to stderr
- Log guest list to log even in non-debug mode
- Resolves: rhbz#813299

* Tue Apr 17 2012 Radek Novacek <rnovacek@redhat.com> 0.6-4
- Fix regression in double fork patch
- Resolves: rhbz#813299

* Wed Mar 28 2012 Radek Novacek <rnovacek@redhat.com> 0.6-3
- Do double fork when daemon is starting
- Resolves: rhbz#806225

* Fri Mar 09 2012 Radek Novacek <rnovacek@redhat.com> 0.6-2
- Add python-suds require
- Requires python-rhsm >= 0.98.6
- Resolves: rhbz#801657

* Thu Mar 01 2012 Radek Novacek <rnovacek@redhat.com> 0.6-1
- Rebase to virt-who-0.6
- Resolves: rhbz#790000

* Wed Oct 12 2011 Radek Novacek <rnovacek@redhat.com> 0.3-3
- Use updateConsumer API instead of updateConsumerFact (fixes limit 255 chars of uuid list)
- Requires python-rhsm >= 0.96.13 
- Resolves: rhbz#743823

* Wed Sep 07 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-2
- Add upstream patch that prevents failure when server not implements /status/ command
- Resolves: rhbz#735793

* Thu Sep 01 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-1
- Add initscript and configuration file

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-2
- Bump release because of tagging in wrong branch

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-1
- Update to upstream version 0.2
- Add Requires: libvirt

* Fri Aug 19 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-2
- Add BuildRoot tag (the package will be in RHEL5)

* Wed Aug 10 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-1
- initial import
